pypi-data
=========

PyPI metadata downloader. `Example`__

Treats PyPI kindly - initialises from a pre-generated archive, updates using
the changelog API.

1. Install with ``pip install pypi-data``.
2. Download initial metadata with ``pypi-data init data``.
3. Run ``pypi-data update data`` when needed.

.. Example: https://pypi.python.org/pypi/requests/json
__ Example
